@@ -53,20 +53,23 @@ with the same context::
 """
 
 import grokcore.viewlet as grok
-from zope.interface import Interface
+
 
 class CavemenViewletManager(grok.ViewletManager):
     grok.name('manage.cavemen')
 
+
 class FredViewlet(grok.Viewlet):
     grok.viewletmanager(CavemenViewletManager)
 
     def render(self):
-        return 'Me Fred'
+        return u"Me Fred"
+
 
 class Cave(grok.Context):
     pass
 
-class Index(grok.CodeView):
+
+class Index(grok.View):
     def render(self):
-        return "hoi"
+        return u"hoi"
